@@ -14,6 +14,6 @@ options = (
       {'type' : 'yn',
       'default': True,
       'help': 'specifies if cw_combatibility css must be activated (needed in production)',
-      'group': 'bootrstrap', 'level': 0,
+      'group': 'bootstrap', 'level': 0,
       }),
 )
